@@ -1,8 +1,7 @@
 # This helps pylint find all subcommands.
-__all__ = ["aws_batch_init", "aws_batch_submit", "init", "import_uhgg", \
+__all__ = ["aws_batch_init", "aws_batch_submit", "init", "database", \
             "annotate_genome", "build_pangenome", "infer_markers", \
-            "build_midasdb", "database", \
-            "build_bowtie2db", "compute_chunks", \
+            "build_midasdb", "build_bowtie2db", "compute_chunks", \
             "run_species", "run_genes", "run_snps", \
             "merge_species", "merge_snps", "merge_genes", \
             "example_subcommand"]
