@@ -10,9 +10,9 @@ import numpy as np
 from pysam import AlignmentFile  # pylint: disable=no-name-in-module
 
 from midas2.common.argparser import add_subcommand
-from midas2.common.utils import tsprint, InputStream, OutputStream, multiprocessing_map, command, cat_files, select_from_tsv, multithreading_map
+from midas2.common.utils import tsprint, InputStream, OutputStream, multiprocessing_map, command, cat_files, select_from_tsv, multithreading_map, args_string
 from midas2.common.bowtie2 import build_bowtie2_db, bowtie2_align, samtools_sort, samtools_index, bowtie2_index_exists, _keep_read
-from midas2.params.schemas import snps_profile_schema, snps_pileup_schema, format_data, snps_chunk_summary_schema, snps_pileup_basic_schema
+from midas2.params.schemas import snps_profile_schema, snps_pileup_schema, format_data, snps_pileup_basic_schema
 from midas2.common.snvs import call_alleles, reference_overlap, update_overlap, mismatches_within_overlaps, query_overlap_qualities
 from midas2.common.utilities import scan_fasta
 from midas2.models.midasdb import MIDAS_DB
@@ -21,7 +21,6 @@ from midas2.models.species import Species, parse_species
 from midas2.params.inputs import MIDASDB_NAMES
 
 
-DEFAULT_MARKER_DEPTH = 5.0
 DEFAULT_MARKER_MEDIAN_DEPTH = 2
 
 DEFAULT_ALN_MAPID = 94.0
@@ -57,17 +56,17 @@ def register_args(main_func):
                            dest='r2',
                            help="FASTA/FASTQ file containing 2nd mate if using paired-end reads.")
 
-    # Prebuilt/predownload
+    # Prebuilt
     subparser.add_argument('--prebuilt_bowtie2_indexes',
                            dest='prebuilt_bowtie2_indexes',
                            type=str,
                            metavar="CHAR",
-                           help=f"Prebuilt bowtie2 database indexes")
+                           help=f"Path to prebuilt rep-genome bowtie2 database indexes")
     subparser.add_argument('--prebuilt_bowtie2_species',
                            dest='prebuilt_bowtie2_species',
                            type=str,
                            metavar="CHAR",
-                           help=f"List of species used for building the prebuild bowtie2 indexes.")
+                           help=f"Path to list of species in the prebuild bowtie2 indexes.")
     subparser.add_argument('--midasdb_name',
                            dest='midasdb_name',
                            type=str,
@@ -78,14 +77,14 @@ def register_args(main_func):
                            dest='midasdb_dir',
                            type=str,
                            default="midasdb",
-                           help=f"Local MIDAS Database path mirroing S3.")
+                           help=f"Path to local MIDAS Database.")
 
     # Species related
     subparser.add_argument('--species_list',
                            dest='species_list',
                            type=str,
                            metavar="CHAR",
-                           help=f"Comma separated list of species ids")
+                           help=f"Comma separated list of species ids OR path to list of species TXT.")
     subparser.add_argument('--select_by',
                            dest='select_by',
                            type=str,
@@ -97,7 +96,7 @@ def register_args(main_func):
                            type=str,
                            metavar="CHAR",
                            default=str(DEFAULT_MARKER_MEDIAN_DEPTH),
-                           help=f"Comman separated correponsding cutoff for filtering species (> XX) ({DEFAULT_MARKER_MEDIAN_DEPTH}, )")
+                           help=f"Comman separated correponsding cutoff to select_by (>XX) ({DEFAULT_MARKER_MEDIAN_DEPTH}, )")
 
     # Alignment flags (Bowtie2 or postprocessing)
     subparser.add_argument('--aln_speed',
@@ -116,14 +115,20 @@ def register_args(main_func):
                            action='store_true',
                            default=False,
                            help='FASTA/FASTQ file in -1 are paired and contain forward AND reverse reads')
+
     subparser.add_argument('--fragment_length',
                            type=float,
                            dest='fragment_length',
                            metavar='FLOAT',
                            default=DEFAULT_MAX_FRAGLEN,
                            help=f"Maximum fragment length for paired reads ({DEFAULT_MAX_FRAGLEN}).")
+    subparser.add_argument('--max_reads',
+                           dest='max_reads',
+                           type=int,
+                           metavar="INT",
+                           help=f"Number of reads to use from input file(s) for read alignment.  (All)")
 
-    #  Pileup flags (samtools, or postprocessing)
+    # Post-alignment filter flags
     subparser.add_argument('--aln_mapid',
                            dest='aln_mapid',
                            type=float,
@@ -160,11 +165,25 @@ def register_args(main_func):
                            type=int,
                            metavar="INT",
                            help=f"Trim ALN_TRIM base-pairs from 3'right end of read ({DEFAULT_ALN_TRIM})")
-
     subparser.add_argument('--paired_only',
                            action='store_true',
                            default=False,
                            help=f"Only recruit properly paired reads for pileup.")
+
+    # Pileup
+    subparser.add_argument('--site_depth',
+                           dest='site_depth',
+                           type=int,
+                           metavar="INT",
+                           default=DEFAULT_SITE_DEPTH,
+                           help=f"Only perform pileup for genomic site covered by post-filtered reads (>={DEFAULT_SITE_DEPTH})")
+    subparser.add_argument('--snp_maf',
+                           dest='snp_maf',
+                           type=float,
+                           metavar="FLOAT",
+                           default=DEFAULT_SNP_MAF,
+                           help=f"Minimum single sample minor-allele_frequency to call an allele present (>={DEFAULT_SNP_MAF}), Values > 0.0 and < 0.5 are accepted.")
+
     subparser.add_argument('--ignore_ambiguous',
                            action='store_true',
                            default=False,
@@ -178,38 +197,19 @@ def register_args(main_func):
                            default=False,
                            help=f"Report majore/minor allele for each genomic sites.")
 
-    # File related
+    # Resource related
     subparser.add_argument('--chunk_size',
                            dest='chunk_size',
                            type=int,
                            metavar="INT",
                            default=DEFAULT_CHUNK_SIZE,
                            help=f"Number of genomic sites for the temporary chunk file  ({DEFAULT_CHUNK_SIZE})")
-    subparser.add_argument('--max_reads',
-                           dest='max_reads',
-                           type=int,
-                           metavar="INT",
-                           help=f"Number of reads to use from input file(s).  (All)")
     subparser.add_argument('--num_cores',
                            dest='num_cores',
                            type=int,
                            metavar="INT",
                            default=DEFAULT_NUM_CORES,
                            help=f"Number of physical cores to use ({DEFAULT_NUM_CORES})")
-
-    subparser.add_argument('--site_depth',
-                           dest='site_depth',
-                           type=int,
-                           metavar="INT",
-                           default=DEFAULT_SITE_DEPTH,
-                           help=f"Minimum number of reads mapped to genomic site ({DEFAULT_SITE_DEPTH})")
-    subparser.add_argument('--snp_maf',
-                           dest='snp_maf',
-                           type=float,
-                           metavar="FLOAT",
-                           default=DEFAULT_SNP_MAF,
-                           help=f"Minimum single sample minor-allele_frequency to call an allele present ({DEFAULT_SNP_MAF}), Values > 0.0 and < 0.5 are accepted.")
-
     return main_func
 
 
@@ -284,7 +284,7 @@ def filter_bam_by_single_read(species_id, repbamfile, filtered_bamfile):
     global dict_of_species
     global sample
 
-    tsprint(f"  MIDAS::filter_bam_by_single_read::{species_id}-0::start filter_bam_by_single_read")
+    tsprint(f"  MIDAS2::filter_bam_by_single_read::{species_id}-0::start filter_bam_by_single_read")
 
     # List of contigs for given species
     sp = dict_of_species[species_id]
@@ -322,7 +322,7 @@ def filter_bam_by_single_read(species_id, repbamfile, filtered_bamfile):
         filtered_bam.write(aln)
     filtered_bam.close()
 
-    tsprint(f"  MIDAS::filter_bam_by_single_read::{species_id}-0::finish filter_bam_by_single_read")
+    tsprint(f"  MIDAS2::filter_bam_by_single_read::{species_id}-0::finish filter_bam_by_single_read")
     return reads_stats
 
 
@@ -333,7 +333,7 @@ def filter_bam_by_proper_pair(species_id, repbamfile, filtered_bamfile):
     global dict_of_species
     global sample
 
-    tsprint(f"  MIDAS::filter_bam_by_proper_pair::{species_id}-0::start filter_bam_by_proper_pair")
+    tsprint(f"  MIDAS2::filter_bam_by_proper_pair::{species_id}-0::start filter_bam_by_proper_pair")
 
     # List of contigs for given species
     sp = dict_of_species[species_id]
@@ -455,7 +455,7 @@ def filter_bam_by_proper_pair(species_id, repbamfile, filtered_bamfile):
         filtered_bam.write(alns["rev"])
     filtered_bam.close()
 
-    tsprint(f"  MIDAS::filter_bam_by_proper_pair::{species_id}-0::finish filter_bam_by_proper_pair")
+    tsprint(f"  MIDAS2::filter_bam_by_proper_pair::{species_id}-0::finish filter_bam_by_proper_pair")
     return reads_stats
 
 
@@ -477,7 +477,7 @@ def sort_bam(pargs):
 
     species_id, numcores = pargs
 
-    filtered_bamfile = sample.get_target_layout("species_bam", species_id) # <species_id> output
+    filtered_bamfile = sample.get_target_layout("species_bam", species_id)
     sorted_bamfile = sample.get_target_layout("species_sorted_bam", species_id)
 
     samtools_sort(filtered_bamfile, sorted_bamfile, global_args.debug, numcores)
@@ -497,17 +497,17 @@ def process_chunk_of_sites(packed_args):
         global dict_of_species
         sp = dict_of_species[species_id]
 
-        tsprint(f"  MIDAS::process_chunk_of_sites::{species_id}-{chunk_id}::wait merge_chunks_per_species")
+        tsprint(f"  MIDAS2::process_chunk_of_sites::{species_id}-{chunk_id}::wait merge_chunks_per_species")
         for _ in range(sp.num_of_snps_chunks):
             semaphore_for_species[species_id].acquire()
-        tsprint(f"  MIDAS::process_chunk_of_sites::{species_id}-{chunk_id}::start merge_chunks_per_species")
+        tsprint(f"  MIDAS2::process_chunk_of_sites::{species_id}-{chunk_id}::start merge_chunks_per_species")
         ret = merge_chunks_per_species(species_id)
-        tsprint(f"  MIDAS::process_chunk_of_sites::{species_id}-{chunk_id}::finish merge_chunks_per_species")
+        tsprint(f"  MIDAS2::process_chunk_of_sites::{species_id}-{chunk_id}::finish merge_chunks_per_species")
         return ret
 
-    tsprint(f"  MIDAS::process_chunk_of_sites::{species_id}-{chunk_id}::start compute_pileup_per_chunk")
+    tsprint(f"  MIDAS2::process_chunk_of_sites::{species_id}-{chunk_id}::start compute_pileup_per_chunk")
     ret = compute_pileup_per_chunk(packed_args)
-    tsprint(f"  MIDAS::process_chunk_of_sites::{species_id}-{chunk_id}::finish compute_pileup_per_chunk")
+    tsprint(f"  MIDAS2::process_chunk_of_sites::{species_id}-{chunk_id}::finish compute_pileup_per_chunk")
 
     return ret
 
@@ -596,12 +596,13 @@ def midas_pileup(packed_args):
         ref_allele = contig_seq[ref_pos]
         row = [contig_id, ref_pos + 1, ref_allele, depth, count_a, count_c, count_g, count_t]
 
+        if depth > 0:
+            aln_stats["contig_total_depth"] += depth
+            aln_stats["contig_covered_bases"] += 1
+
         if depth < global_args.site_depth:
             continue
 
-        aln_stats["contig_total_depth"] += depth
-        aln_stats["contig_covered_bases"] += 1
-
         # Ignore ambiguous sites
         if global_args.ignore_ambiguous:
             rc = [_ for _ in [count_a, count_c, count_g, count_t] if _ > 0]
@@ -700,47 +701,40 @@ def compute_chunk_aln_summary(list_of_contig_aln_stats, species_ids_of_interest)
     return dict_of_chunk_aln_stats
 
 
-def write_species_pileup_summary(chunks_pileup_summary, snps_summary_outfile, chunk_output, dict_of_chunk_aln_stats):
+def write_species_pileup_summary(chunks_pileup_summary, snps_summary_outfile, dict_of_chunk_aln_stats):
     """ Collect species pileup aln stats from all chunks and write to file """
 
     species_pileup_summary = defaultdict(dict)
 
-    with OutputStream(chunk_output) as stream:
-        stream.write("\t".join(snps_chunk_summary_schema.keys()) + "\n")
+    for records in chunks_pileup_summary:
+        if records is True:
+            continue
+        for record in records:
+            species_id = record["species_id"]
+            chunk_id = record["chunk_id"]
+            contig_id = record["contig_id"]
 
-        for records in chunks_pileup_summary:
-            if records is True:
-                continue
+            record["aligned_reads"] = dict_of_chunk_aln_stats[species_id][chunk_id][contig_id]["aligned_reads"]
+            record["mapped_reads"] = dict_of_chunk_aln_stats[species_id][chunk_id][contig_id]["mapped_reads"]
 
-            for record in records:
-                species_id = record["species_id"]
-                chunk_id = record["chunk_id"]
-                contig_id = record["contig_id"]
-
-                record["aligned_reads"] = dict_of_chunk_aln_stats[species_id][chunk_id][contig_id]["aligned_reads"]
-                record["mapped_reads"] = dict_of_chunk_aln_stats[species_id][chunk_id][contig_id]["mapped_reads"]
-
-                stream.write("\t".join(map(format_data, record.values())) + "\n")
-
-                if species_id not in species_pileup_summary:
-                    species_pileup_summary[species_id] = {
-                        "species_id": species_id,
-                        "genome_length": 0,
-                        "covered_bases": 0,
-                        "total_depth": 0,
-                        "aligned_reads": 0,
-                        "mapped_reads": 0,
-                        "fraction_covered": 0.0,
-                        "mean_coverage": 0.0
-                        }
-
-                curr_species_pileup = species_pileup_summary.get(species_id)
-                curr_species_pileup["genome_length"] += record["chunk_length"]
-                curr_species_pileup["total_depth"] += record["contig_total_depth"]
-                curr_species_pileup["covered_bases"] += record["contig_covered_bases"]
-                curr_species_pileup["aligned_reads"] += record["aligned_reads"]
-                curr_species_pileup["mapped_reads"] += record["mapped_reads"]
+            if species_id not in species_pileup_summary:
+                species_pileup_summary[species_id] = {
+                    "species_id": species_id,
+                    "genome_length": 0,
+                    "covered_bases": 0,
+                    "total_depth": 0,
+                    "aligned_reads": 0,
+                    "mapped_reads": 0,
+                    "fraction_covered": 0.0,
+                    "mean_coverage": 0.0
+                    }
 
+            curr_species_pileup = species_pileup_summary.get(species_id)
+            curr_species_pileup["genome_length"] += record["chunk_length"]
+            curr_species_pileup["total_depth"] += record["contig_total_depth"]
+            curr_species_pileup["covered_bases"] += record["contig_covered_bases"]
+            curr_species_pileup["aligned_reads"] += record["aligned_reads"]
+            curr_species_pileup["mapped_reads"] += record["mapped_reads"]
 
     # Secondary round compute: need to loop over species to compute fraction_covered
     for species_id in species_pileup_summary.keys():
@@ -769,6 +763,9 @@ def run_snps(args):
         sample = Sample(args.sample_name, args.midas_outdir, "snps")
         sample.create_dirs(["outdir", "tempdir"], args.debug, quiet=True)
 
+        with OutputStream(sample.get_target_layout("snps_log")) as stream:
+            stream.write(f"Single sample SNV calling in subcommand {args.subcommand} with args\n{json.dumps(args_string(args), indent=4)}\n")
+
         species_list = parse_species(args)
 
         # Prepare Bowtie2 genome database path and name, prebuilt or to be built.
@@ -796,32 +793,32 @@ def run_snps(args):
 
         species_ids_of_interest = species_list if no_filter else sample.select_species(args, species_list)
         species_counts = len(species_ids_of_interest)
-
-        sample.create_species_subdirs(species_ids_of_interest, "temp", args.debug, quiet=True)
         assert species_counts > 0, f"No (specified) species pass the marker_depth filter, please adjust the marker_depth or species_list"
         tsprint(len(species_ids_of_interest))
 
+        sample.create_species_subdirs(species_ids_of_interest, "temp", args.debug, quiet=True)
+
         # Fetch representative genome fastas for each species (multiprocessing)
-        tsprint(f"MIDAS::design_chunks::start")
+        tsprint(f"MIDAS2::design_chunks::start")
         num_cores_download = min(args.num_cores, species_counts)
         midas_db = MIDAS_DB(os.path.abspath(args.midasdb_dir), args.midasdb_name, num_cores_download)
-
+        midas_db.fetch_files("repgenome", species_ids_of_interest)
         arguments_list = design_chunks(species_ids_of_interest, midas_db, args.chunk_size)
-        tsprint(f"MIDAS::design_chunks::finish")
+        tsprint(f"MIDAS2::design_chunks::finish")
 
         # Build Bowtie indexes for species in the restricted species profile
+        tsprint(f"MIDAS2::build_bowtie2db::start")
         contigs_files = midas_db.fetch_files("representative_genome", species_ids_of_interest)
-        tsprint(f"MIDAS::build_bowtie2db::start")
         build_bowtie2_db(bt2db_dir, bt2db_name, contigs_files, args.num_cores)
-        tsprint(f"MIDAS::build_bowtie2db::finish")
+        tsprint(f"MIDAS2::build_bowtie2db::finish")
 
-        tsprint(f"MIDAS::bowtie2_align::start")
+        tsprint(f"MIDAS2::bowtie2_align::start")
         repgenome_bamfile = sample.get_target_layout("snps_repgenomes_bam")
         bowtie2_align(bt2db_dir, bt2db_name, repgenome_bamfile, args)
         samtools_index(repgenome_bamfile, args.debug, args.num_cores)
-        tsprint(f"MIDAS::bowtie2_align::finish")
+        tsprint(f"MIDAS2::bowtie2_align::finish")
 
-        tsprint(f"MIDAS::filter_bam::start")
+        tsprint(f"MIDAS2::filter_bam::start")
         args_list = []
         for species_id in species_ids_of_interest:
             repgenome_bamfile = sample.get_target_layout("snps_repgenomes_bam") # input
@@ -831,19 +828,23 @@ def run_snps(args):
 
         cores_per_species = max(4, floor(args.num_cores/species_counts))
         multiprocessing_map(sort_bam, [(species_id, cores_per_species) for species_id in species_ids_of_interest], floor(args.num_cores/cores_per_species))
-        tsprint(f"MIDAS::filter_bam::finish")
+        tsprint(f"MIDAS2::filter_bam::finish")
 
-        tsprint(f"MIDAS::multiprocessing_map::start")
+        tsprint(f"MIDAS2::multiprocessing_map::start")
         chunks_pileup_summary = multiprocessing_map(process_chunk_of_sites, arguments_list, args.num_cores)
-        tsprint(f"MIDAS::multiprocessing_map::finish")
+        tsprint(f"MIDAS2::multiprocessing_map::finish")
 
-        tsprint(f"MIDAS::write_species_pileup_summary::start")
+        tsprint(f"MIDAS2::write_species_pileup_summary::start")
         snps_summary_fp = sample.get_target_layout("snps_summary")
-        snps_chunk_summary_fp = sample.get_target_layout("snps_chunk_summary")
 
         dict_of_chunk_aln_stats = compute_chunk_aln_summary(list_of_contig_aln_stats, species_ids_of_interest)
-        write_species_pileup_summary(chunks_pileup_summary, snps_summary_fp, snps_chunk_summary_fp, dict_of_chunk_aln_stats)
-        tsprint(f"MIDAS::write_species_pileup_summary::finish")
+        write_species_pileup_summary(chunks_pileup_summary, snps_summary_fp, dict_of_chunk_aln_stats)
+        tsprint(f"MIDAS2::write_species_pileup_summary::finish")
+
+        if not args.debug:
+            sample.remove_dirs(["tempdir"])
+            if not args.prebuilt_bowtie2_indexes:
+                sample.remove_dirs(["bt2_indexes_dir"])
 
     except Exception as error:
         if not args.debug:
@@ -856,5 +857,5 @@ def run_snps(args):
 
 @register_args
 def main(args):
-    tsprint(f"Single nucleotide polymorphisms calling in subcommand {args.subcommand} with args\n{json.dumps(vars(args), indent=4)}")
+    tsprint(f"Single sample SNV calling in subcommand {args.subcommand} with args\n{json.dumps(vars(args), indent=4)}")
     run_snps(args)
